==> flutter_iiif-0.0.1.tar.gz: lib/src/IIIFImage.dart <==
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'dart:convert' show json;

import 'IIIFImageMeta.dart';
import 'IIIFImageSettings.dart';
import 'IIIFGrid.dart';

class IIIFImage extends StatefulWidget {
  final IIIFImageSettings settings;

  IIIFImage({Key key, @required this.settings}) : super(key: key);

  //
  @override
  _IIIFImageState createState() => _IIIFImageState(settings: settings);
}

class _IIIFImageState extends State<IIIFImage> {
  final IIIFImageSettings settings;

  bool _loading = true;
  bool _error = false;
  _IIIFImageState({this.settings});

  @override
  void initState() {
    super.initState();
    _fetchMetaData();
    settings.notifier.addListener(_fetchMetaData);
  }

  //
  //
  //
  dynamic _fetchMetaData() async {
    print('_fetchMetaData ${settings.assetID}');
    setState(() {
      _loading = true;
    });
    final http.Response response = await http.get(settings.server + settings.assetID + '/info.json');
    if (response.statusCode == 200) {
      dynamic data = json.decode(response.body);
      settings.meta = IIIFImageMeta.fromJSON(data);
      setState(() {
        _loading = false;
      });
    } else {
      // ERROR
      setState(() {
        _error = true;
      });
    }
  }

  //
  //
  //
  // BUILD
  @override
  Widget build(BuildContext context) {
    if (_error) {
      return Center(child: Icon(Icons.error));
    } else if (_loading) {
      return Center(child: CircularProgressIndicator());
    } else {
      return IIIFGrid(settings: settings);
    }
  }
}

==> flutter_iiif-0.1.1.tar.gz: lib/src/IIIFImage.dart <==
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'dart:convert' show json;

import 'IIIFImageMeta.dart';
import 'IIIFImageSettings.dart';
import 'IIIFGrid.dart';

class IIIFImage extends StatefulWidget {
  final IIIFImageSettings settings;

  IIIFImage({Key key, @required this.settings}) : super(key: key);

  //
  @override
  _IIIFImageState createState() => _IIIFImageState(settings: settings);
}

class _IIIFImageState extends State<IIIFImage> {
  final IIIFImageSettings settings;

  bool _loading = true;
  bool _error = false;
  _IIIFImageState({this.settings});

  @override
  void initState() {
    super.initState();
    _fetchMetaData();
    settings.notifier.addListener(_fetchMetaData);
  }

  //
  //
  //
  dynamic _fetchMetaData() async {
    print('_fetchMetaData ${settings.assetID}');
    setState(() {
      _loading = true;
    });
    final http.Response response =
        await http.get(settings.server + settings.assetID + '/info.json');

    print(response.body);
    if (response.statusCode == 200) {
      dynamic data = json.decode(response.body);
      settings.meta = IIIFImageMeta.fromJSON(data);
      setState(() {
        _loading = false;
      });
    } else {
      // ERROR
      setState(() {
        _error = true;
      });
    }
  }

  //
  //
  //
  // BUILD
  @override
  Widget build(BuildContext context) {
    if (_error) {
      return Center(child: Icon(Icons.error));
    } else if (_loading) {
      return Center(child: CircularProgressIndicator());
    } else {
      return IIIFGrid(settings: settings);
    }
  }
}
